#
# spec file for package xapian-bindings
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with php
%define php_extension_dir %(php-config --extension-dir)
%bcond_with mono

%if 0%{?suse_version} >= 1320 && 0%{?is_opensuse}
%bcond_without sphinx
%define phpver php7
%define phppkg php7
%else
%bcond_with sphinx
%define phpver php5
%define phppkg php
%endif

Name:           xapian-bindings
Version:        1.4.5
Release:        lp152.3.10
Summary:        Bindings for xapian
License:        GPL-2.0
Group:          Development/Languages/Other
Url:            http://www.xapian.org/
Source0:        http://www.oligarchy.co.uk/xapian/%{version}/%{name}-%{version}.tar.xz
Source1:        http://www.oligarchy.co.uk/xapian/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         do-not-use-sphinx.diff
Patch1:         fix-php7-directory.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  java-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  libxapian-devel = %{version}
%if %{with mono}
BuildRequires:  mono-devel
%endif

%if %{with php}
BuildRequires:  %{phpver}-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  python-devel >= 2.6
BuildRequires:  python-setuptools
%if %{with sphinx}
BuildRequires:  python-sphinx
BuildRequires:  python3-Sphinx
%endif
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  ruby-devel
BuildRequires:  tcl-devel
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.

%package -n python-xapian
Summary:        Files needed for developing Python scripts which use Xapian
Group:          Development/Libraries/Python
Provides:       python2-xapian = %{version}

%description -n python-xapian
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing Python 2 scripts
which use Xapian.

%package -n python3-xapian
Summary:        Files needed for developing Python scripts which use Xapian
Group:          Development/Libraries/Python

%description -n python3-xapian
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing Python 3 scripts
which use Xapian.

%if %{with php}
%package -n %{phppkg}-xapian
Summary:        Files needed for developing PHP scripts which use Xapian
Group:          Productivity/Networking/Web/Servers
Requires:       %{phpver}

%description -n %{phppkg}-xapian
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing PHP scripts
which use Xapian.
%endif

%package -n ruby-xapian
Summary:        Files needed for developing Ruby scripts which use Xapian
Group:          Development/Languages/Ruby
Requires:       ruby

%description -n ruby-xapian
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing Ruby scripts
which use Xapian.

%package -n tcl8-xapian
Summary:        Files needed for developing TCL scripts which use Xapian
Group:          Development/Libraries/Tcl
Requires:       tcl

%description -n tcl8-xapian
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing Tcl scripts
which use Xapian.

%package -n xapian-csharp
Summary:        Files needed for developing C# applications which use Xapian
Group:          Development/Languages/Mono
Requires:       mono-core

%description -n xapian-csharp
Xapian is a probabilistic information retrieval library. It offers an
adaptable toolkit that allows developers to add advanced indexing and
search facilities to applications.
This package provides the files needed for developing C# applications
which use Xapian.

%prep
%setup -q
%if %{without sphinx}
%patch0 -p1
%endif
%if %{with php} && %{phpver} == php7
%patch1 -p1
%endif

%build

autoreconf -vfi

%configure        \
    --with-python \
    --with-python3 \
%if %{with php}
    --with-%{phppkg} \
%endif
    --with-ruby   \
    --with-tcl    \
%if %{without mono}
    --without-csharp \
%else
    --with-csharp \
%endif
    --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
make install DESTDIR=%{?buildroot} %{?_smp_mflags}

%files -n python-xapian
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/python/
%{python_sitearch}/xapian/

%files -n python3-xapian
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/python3/
%{python3_sitearch}/xapian/

%if %{with php}
%files -n %{phppkg}-xapian
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/php/
%{php_extension_dir}/xapian.so
%{_datadir}/%{phpver}/xapian.php
%endif

%files -n ruby-xapian
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/ruby/
%{_libdir}/ruby/site_ruby/%{rb_ver}/%{rb_arch}/_xapian.so
%{_libdir}/ruby/site_ruby/%{rb_ver}/xapian.rb

%files -n tcl8-xapian
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/tcl8/
%{_libdir}/tcl/xapian%{version}/

%if %{with mono}
%files -n xapian-csharp
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog HACKING NEWS README TODO
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/csharp/
%{_libdir}/_XapianSharp.so
%dir %{_libdir}/mono/
%{_libdir}/mono/XapianSharp/
%dir %{_libdir}/mono/gac/
%{_libdir}/mono/gac/XapianSharp/
%endif

%changelog
* Thu Dec 14 2017 alarrosa@suse.com
- Update to 1.4.5
  * see http://xapian.org/docs/xapian-bindings-1.4.5/NEWS
* Mon Sep 11 2017 alarrosa@suse.com
- Create a new php7-xapian package in Tumbleweed instead of using php5
  which will be removed soon (boo#1058105)
- Add fix-php7-directory.patch to install xapian.php to the right directory.
- Disable creation of php bindings by default due to
  https://trac.xapian.org/wiki/FAQ/PHP%%20Bindings%%20Package
- To build the php bindings locally, use :
  * osc build --with=php
  or download the src.rpm file and use:
  * rpmbuild --rebuild xapian-bindings-1.4.4-0.src.rpm -D "with_php 1"
* Fri Jun 30 2017 alarrosa@suse.com
- Update to 1.4.4
  * see http://xapian.org/docs/xapian-bindings-1.4.4/NEWS
- Rebase do-not-use-sphinx.diff
* Fri Jun 30 2017 jengelh@inai.de
- Trim filler words from descriptions.
- %%packages need not be %%if guarded (only their %%files),
  so trim that too.
* Mon Jun 26 2017 tbechtold@suse.com
- add Provides for python2-xapian
* Wed Feb  1 2017 alarrosa@suse.com
- Update to 1.4.3
  * see http://xapian.org/docs/xapian-bindings-1.4.3/NEWS
- xapian-bindings 1.4.3 requires Python >= 2.6
- Update to 1.4.2
  * see http://xapian.org/docs/xapian-bindings-1.4.2/NEWS
- Added BuildRequire python3-Sphinx
- Drop automake.patch, which is not needed anymore
- Added do-not-use-sphinx.diff to remove the need of python3-Sphinx
  on distributions that don't have it
* Tue Nov 22 2016 bosim@opensuse.org
- Python3 support
- Added automake patch for building with python3 (github PR 126)
* Fri Nov 11 2016 alarrosa@suse.com
- Update to 1.4.1
  * see http://xapian.org/docs/xapian-bindings-1.4.1/NEWS
- Specify in BuildRequires that php >= 5.5 is needed .
* Sat Jul  9 2016 tittiatcoke@gmail.com
- Update to 1.4.0
  * see http://xapian.org/docs/xapian-bindings-1.4.0/NEWS
- Drop patch replaced-swig-zend-error-noreturn-flag.patch
* Wed Apr 13 2016 tittiatcoke@gmail.com
- Update to 1.2.23
  * see http://xapian.org/docs/xapian-bindings-1.2.23/NEWS
* Tue Jul 21 2015 jengelh@inai.de
- Remove unnecessary buildrequire on update-alternatives:
  there are no scriptlets that make use of it.
  Drop %%clean, it too is unnecessary for OBS.
* Thu May 21 2015 tittiatcoke@gmail.com
- Update to 1.2.21
  * see http://xapian.org/docs/xapian-bindings-1.2.21/NEWS
* Thu Apr  2 2015 dmueller@suse.com
- make building of csharp bindings optional for architectures
  that do not provide mono
* Thu Mar 12 2015 mpluskal@suse.com
- Update to 1.2.20
  * See http://xapian.org/docs/xapian-bindings-1.2.20/NEWS
* Thu Feb 19 2015 mpluskal@suse.com
- Tiny spec file cleanups
- Enable tests during build
- Add gpg signature
* Tue Oct 21 2014 tittiatcoke@gmail.com
- Update to version 1.2.19
  ? http://xapian.org/docs/xapian-bindings-1.2.19/NEWS
* Wed Jan 29 2014 hrvoje.senjan@gmail.com
- Update to version 1.2.17
  * http://svn.xapian.org/*checkout*/tags/1.2.17/xapian-bindings/NEWS
* Wed Dec 18 2013 tittiatcoke@gmail.com
- Update to version 1.2.16
  * http://svn.xapian.org/*checkout*/tags/1.2.16/xapian-bindings/NEWS
* Thu May 30 2013 tittiatcoke@gmail.com
- Update to version 1.2.15
  * http://svn.xapian.org/*checkout*/tags/1.2.15/xapian-bindings/NEWS
* Tue Dec 25 2012 mlin@suse.com
- Added patch (replaced-swig-zend-error-noreturn-flag.patch)  that
  is replacing the -DSWIG_ZEND_ERROR_NORETURN=zend_error_noreturn
  flag to workaround a PHP bug on some platforms/architectures by
  compiling with -DSWIG_ZEND_ERROR_NORETURN=zend_error, for example
  no-return-in-nonvoid-function issue
* Fri Dec 21 2012 mlin@suse.com
- Update to version 1.2.12
  * No changes since 1.2.11 except to bump the version - this release
    was made to fix an incorrect library version information update
    in xapian-core 1.2.11.
  Perl:
  * In generated C++ code, pass 0 instead of NULL for non-pointer
    parameter to av_fetch() (spotted due to GCC 4.7 warning).
  PHP:
  * Fix "make check" to work for PHP when building from a release
    tarball with srcdir != builddir.
  * Work around "undefined symbol: zend_error_noreturn" error.
  CSharp:
  * Use -keyfile and -keycontainer options to the C# compiler,
    because it warns us to do this instead of setting them in
    AssemblyInfo.cs.
  * Use diff's -c option when comparing the files SWIG generated
    against those we were expecting to get as the output should be
    easier to understand.
  * Sort both the lists of expected and of found SWIG-generated
    sources with Perl, to avoid problems with locale-specific sort
    orders.
  Java-SWIG:
  * Remove now superfluous old check that SWIG generated at least the
    sources we want - we now check it generated *exactly* the sources
    we want.
  * Use diff's -c option when comparing the files SWIG generated against
    those we were expecting to get as the output should be easier to
    understand.
  * Sort both the lists of expected and of found SWIG-generated sources
    with Perl, to avoid problems with locale-specific sort orders.
  * See http://svn.xapian.org/*checkout*/tags/1.2.12/xapian-bindings/NEWS
* Thu Dec 29 2011 dmueller@suse.de
- update to 1.2.8:
  * Wrap user-subclassable functor objects by allowing the user to pass a
    Lua function where the functor object would be passed in the C++ API.
  * Fix "PHP Notice:  Undefined variable: r in xapian.php".  (Fixes bug#576)
  * The PHP bindings will now work again with a version of PHP built with ZTS
    enabled (which is the default on Microsoft Windows).  This was broken by
    the changes to support subclassing in PHP in the version of SWIG used since
    1.2.6.
  * Add a module docstring.  (Fixes bug #573)
  * The python testsuite now checks for object leaks during each testcase.
  * In test_matchingterms_iter, run the code we're testing for leaks twice, and
    only check for leaks the second time to avoid falsely reporting a leak when
    some cached value gets initialised under Python 2.5.
  * Wrap optional prefix parameter to Database::allterms.
* Wed Sep 21 2011 coolo@suse.com
- remove %%debug_package macro
* Tue Sep 13 2011 prusnak@opensuse.org
- updated to 1.2.7
  General:
  * Add missing wrappers for Database::has_positions() and
    TermIterator::positionlist_count(), and correct the return type of
    Database::get_doclength() from double to Xapian::termcount.
  CSharp:
  * Fix iterator ++ and -- so that the reference to the object
    isn't released prematurely, which was causing an occasional
    crash if the garbage collection happened at just the wrong moment,
  * Add test coverage for QueryParser.ParseQuery() with flags argument.
  * Wrap Query::MatchAll and Query::MatchNothing. (ticket#158)
  Java:
  * SmokeTest.java: Fix == comparisons with strings to use equals().
  * Add test that string passing is zero byte safe.
  * Fix MyExpandDecider.accept() to really check the passed parameter.
  Java-SWIG:
  * Put the SWIG-generated Java bindings in package org.xapian.
  * Wrap Query::MatchAll and Query::MatchNothing. (ticket#158)
  * SmokeTest.java: Fix == comparisons with literal strings to
    use equals()
  * Add test that string passing is zero byte safe.
  * Fix MyExpandDecider.accept() to really check the passed parameter.
  * Fix the compile JNI code to have a .jnilib extension on Mac OS X.
  * Create an HTML documentation page based on java/README.
  * Copy java examples from the hand-coded JNI ones.
  * docs/examples/SimpleIndex.java: Update to use commit() rather
    than flush().
  * Wrap Query::MatchAll and Query::MatchNothing. (ticket#158)
  * Check that exactly the sources we expect are generated, and add
    some sources which were missing from the list.
  Perl:
  * Wrap MatchAll and MatchNothing for Perl (as
    Search::Xapian::Query::MatchAll and
    Search::Xapian::Query::MatchNothing).  (ticket#158)
  * perl/t/termgenerator.t: Test TermIterator::index_text() with
    two arguments.
  * perl/t/symbol-test.t: Fix to work when built against an installed
    xapian-core.  (ticket#558)
  PHP:
  * Wrap MatchAll and MatchNothing for PHP as XapianQuery::MatchAll() and
    XapianQuery::MatchNothing(). (ticket#158)
  Ruby:
  * Wrap MatchAll and MatchNothing for Ruby.  (ticket#158)
* Thu Jan 20 2011 alex@rosedu.org
- updated to 1.2.5
* Thu Jan 20 2011 prusnak@opensuse.org
- updated to 1.2.4
* Tue Nov 20 2007 mrueckert@suse.de
- updated java build requires
* Tue Nov 20 2007 mrueckert@suse.de
- fixed filelist
* Mon Nov 19 2007 mrueckert@suse.de
- update to version 1.0.4
* Sun Jun 24 2007 mrueckert@suse.de
- update to version 1.0.1
* Sat Nov 11 2006 mrueckert@suse.de
- initial package of version 0.9.9
